Class: Aws::Support::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Support::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-support/client.rb,
sig/client.rbs
Overview
An API client for Support. To construct a client, you need to configure a :region and :credentials.
client = Aws::Support::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddAttachmentsToSetResponseSuccess, _AddCommunicationToCaseResponseSuccess, _CompleteAttachmentUploadResponseSuccess, _CreateCaseResponseSuccess, _DescribeAttachmentResponseSuccess, _DescribeAttachmentUploadStatusResponseSuccess, _DescribeCasesResponseSuccess, _DescribeCommunicationsResponseSuccess, _DescribeCreateCaseOptionsResponseSuccess, _DescribeServicesResponseSuccess, _DescribeSeverityLevelsResponseSuccess, _DescribeSupportedLanguagesResponseSuccess, _DescribeTrustedAdvisorCheckRefreshStatusesResponseSuccess, _DescribeTrustedAdvisorCheckResultResponseSuccess, _DescribeTrustedAdvisorCheckSummariesResponseSuccess, _DescribeTrustedAdvisorChecksResponseSuccess, _GetAttachmentDownloadLinkResponseSuccess, _GetAttachmentUploadLinksResponseSuccess, _RefreshTrustedAdvisorCheckResponseSuccess, _ResolveCaseResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_attachments_to_set(params = {}) ⇒ Types::AddAttachmentsToSetResponse
Adds one or more attachments to an attachment set.
-
#add_communication_to_case(params = {}) ⇒ Types::AddCommunicationToCaseResponse
Adds additional customer communication to a Amazon Web Services Support case.
-
#complete_attachment_upload(params = {}) ⇒ Types::CompleteAttachmentUploadResponse
Completes an attachment upload that was started with GetAttachmentUploadLinks.
-
#create_case(params = {}) ⇒ Types::CreateCaseResponse
Creates a case in the Amazon Web Services Support Center.
-
#describe_attachment(params = {}) ⇒ Types::DescribeAttachmentResponse
Returns the attachment that has the specified ID.
-
#describe_attachment_upload_status(params = {}) ⇒ Types::DescribeAttachmentUploadStatusResponse
Returns the current status, file name, and progress of a multipart attachment upload that was started with GetAttachmentUploadLinks.
-
#describe_cases(params = {}) ⇒ Types::DescribeCasesResponse
Returns a list of cases that you specify by passing one or more case IDs.
-
#describe_communications(params = {}) ⇒ Types::DescribeCommunicationsResponse
Returns communications and attachments for one or more support cases.
-
#describe_create_case_options(params = {}) ⇒ Types::DescribeCreateCaseOptionsResponse
Returns a list of CreateCaseOption types along with the corresponding supported hours and language availability.
-
#describe_services(params = {}) ⇒ Types::DescribeServicesResponse
Returns the current list of Amazon Web Services services and a list of service categories for each service.
-
#describe_severity_levels(params = {}) ⇒ Types::DescribeSeverityLevelsResponse
Returns the list of severity levels that you can assign to a support case.
-
#describe_supported_languages(params = {}) ⇒ Types::DescribeSupportedLanguagesResponse
Returns a list of supported languages for a specified
categoryCode,issueTypeandserviceCode. -
#describe_trusted_advisor_check_refresh_statuses(params = {}) ⇒ Types::DescribeTrustedAdvisorCheckRefreshStatusesResponse
Returns the refresh status of the Trusted Advisor checks that have the specified check IDs.
-
#describe_trusted_advisor_check_result(params = {}) ⇒ Types::DescribeTrustedAdvisorCheckResultResponse
Returns the results of the Trusted Advisor check that has the specified check ID.
-
#describe_trusted_advisor_check_summaries(params = {}) ⇒ Types::DescribeTrustedAdvisorCheckSummariesResponse
Returns the results for the Trusted Advisor check summaries for the check IDs that you specified.
-
#describe_trusted_advisor_checks(params = {}) ⇒ Types::DescribeTrustedAdvisorChecksResponse
Returns information about all available Trusted Advisor checks, including the name, ID, category, description, and metadata.
-
#get_attachment_download_link(params = {}) ⇒ Types::GetAttachmentDownloadLinkResponse
Returns a presigned download URL for an attachment that is associated with a case communication.
-
#get_attachment_upload_links(params = {}) ⇒ Types::GetAttachmentUploadLinksResponse
Returns one or more presigned upload URLs for uploading a large file attachment to a support case by using a multipart upload workflow.
-
#refresh_trusted_advisor_check(params = {}) ⇒ Types::RefreshTrustedAdvisorCheckResponse
Refreshes the Trusted Advisor check that you specify using the check ID.
-
#resolve_case(params = {}) ⇒ Types::ResolveCaseResponse
Resolves a support case.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-support/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2399 2400 2401 |
# File 'lib/aws-sdk-support/client.rb', line 2399 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2402 2403 2404 |
# File 'lib/aws-sdk-support/client.rb', line 2402 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_attachments_to_set(params = {}) ⇒ Types::AddAttachmentsToSetResponse
Adds one or more attachments to an attachment set.
An attachment set is a temporary container for attachments that you
add to a case or case communication. The set is available for 1 hour
after it's created. The expiryTime returned in the response is when
the set expires.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
88 |
# File 'sig/client.rbs', line 88
def add_attachments_to_set: (
|
#add_communication_to_case(params = {}) ⇒ Types::AddCommunicationToCaseResponse
Adds additional customer communication to a Amazon Web Services
Support case. Use the caseId parameter to identify the case to which
to add communication. To list a set of email addresses to copy on the
communication, use the ccEmailAddresses parameter. The
communicationBody value contains the text of the communication.
To attach files larger than 5 MB to the communication, use the
uploadIds parameter.
Amazon Web Services Support automatically redacts sensitive
information from support cases to protect your data. The following
information is replaced with [REDACTED_BY_Amazon Web Services] and
is not stored:
-
Amazon Web Services secret keys - The complete key is replaced. Example:
[REDACTED_BY_Amazon Web Services] -
Private keys - The complete key is replaced. Example:
[REDACTED_BY_Amazon Web Services] -
Credit card numbers - The number is redacted, but the last 4 digits remain. Example:
[REDACTED_BY_Amazon Web Services]-7016
This sensitive information is never required by Amazon Web Services Support.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
105 |
# File 'sig/client.rbs', line 105
def add_communication_to_case: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 |
# File 'lib/aws-sdk-support/client.rb', line 2372 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Support') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-support' context[:gem_version] = '1.95.0' Seahorse::Client::Request.new(handlers, context) end |
#complete_attachment_upload(params = {}) ⇒ Types::CompleteAttachmentUploadResponse
Completes an attachment upload that was started with
GetAttachmentUploadLinks. After you upload a part of the file to its
presigned Amazon S3 URL, call CompleteAttachmentUpload with the
partIndex and eTag of that part. You can include one part per
call, or multiple parts in a single call. After
CompleteAttachmentUpload has been called for every part of the file,
the service processes the upload asynchronously. The
attachment-ready status might not be reflected immediately. Use
DescribeAttachmentUploadStatus to poll for the uploadStatus to
become attachment-ready before passing the uploadId to CreateCase
or AddCommunicationToCase.
120 |
# File 'sig/client.rbs', line 120
def complete_attachment_upload: (
|
#create_case(params = {}) ⇒ Types::CreateCaseResponse
Creates a case in the Amazon Web Services Support Center. This operation is similar to how you create a case in the Amazon Web Services Support Center Create Case page.
The Amazon Web Services Support API doesn't support requesting service limit increases. You can submit a service limit increase in the following ways:
-
Submit a request from the Amazon Web Services Support Center Create Case page.
-
Use the Service Quotas RequestServiceQuotaIncrease operation.
Amazon Web Services Support automatically redacts sensitive
information from support cases to protect your data. The following
information is replaced with [REDACTED_BY_Amazon Web Services] and
is not stored:
-
Amazon Web Services secret keys - The complete key is replaced. Example:
[REDACTED_BY_Amazon Web Services] -
Private keys - The complete key is replaced. Example:
[REDACTED_BY_Amazon Web Services] -
Credit card numbers - The number is redacted, but the last 4 digits remain. Example:
[REDACTED_BY_Amazon Web Services]-7016
This sensitive information is never required by Amazon Web Services Support.
A successful CreateCase request returns a Amazon Web Services
Support case number. You can use the DescribeCases operation and
specify the case number to get existing Amazon Web Services Support
cases. After you create a case, use the AddCommunicationToCase
operation to add additional communication or attachments to an
existing case.
The caseId is separate from the displayId that appears in the
Amazon Web Services Support Center. Use the DescribeCases
operation to get the displayId.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
137 |
# File 'sig/client.rbs', line 137
def create_case: (
|
#describe_attachment(params = {}) ⇒ Types::DescribeAttachmentResponse
Returns the attachment that has the specified ID. Attachments can include screenshots, error logs, or other files that describe your issue. Attachment IDs are generated by the case management system when you add an attachment to a case or case communication. Attachment IDs are returned in the AttachmentDetails objects that are returned by the DescribeCommunications operation.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
DescribeAttachment can't return attachments larger than 5 MB. If
the specified attachmentId refers to an attachment larger than 5 MB,
the request fails with InvalidParameterValueException.
To download an attachment of any size, including attachments larger
than 5 MB, use GetAttachmentDownloadLink. GetAttachmentDownloadLink
returns an Amazon S3 presigned URL that you can use to download the
attachment directly.
157 |
# File 'sig/client.rbs', line 157
def describe_attachment: (
|
#describe_attachment_upload_status(params = {}) ⇒ Types::DescribeAttachmentUploadStatusResponse
Returns the current status, file name, and progress of a multipart
attachment upload that was started with GetAttachmentUploadLinks. Use
this operation to track where an upload is in the workflow. While
parts are still being uploaded and reported through
CompleteAttachmentUpload, the uploadStatus is attachment-not-ready
and uploadProgress reports the total number of parts and how many
have been completed so far. After every part has been reported and the
service finishes processing the upload asynchronously, the
uploadStatus becomes attachment-ready and the uploadId can be
attached to a case through CreateCase or AddCommunicationToCase.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
170 |
# File 'sig/client.rbs', line 170
def describe_attachment_upload_status: (
|
#describe_cases(params = {}) ⇒ Types::DescribeCasesResponse
Returns a list of cases that you specify by passing one or more case
IDs. You can use the afterTime and beforeTime parameters to filter
the cases by date. You can set values for the includeResolvedCases
and includeCommunications parameters to specify how much information
to return.
The response returns the following in JSON format:
-
One or more CaseDetails data types.
-
One or more
nextTokenvalues, which specify where to paginate the returned records represented by theCaseDetailsobjects.
Case data is available for 24 months after creation. If a case was created more than 24 months ago, a request might return an error.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
Each Communication returned by this operation includes attachment information in two fields:
-
attachmentSet: returns only attachments that are 5 MB or smaller. Attachments larger than 5 MB are not included in this field. -
attachments: returns all attachments regardless of size.
Amazon Web Services recommends that you use the attachments field
and download each attachment with GetAttachmentDownloadLink, which
supports attachments of any size. The attachmentSet field and
DescribeAttachment return only attachments that are 5 MB or smaller.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
182 |
# File 'sig/client.rbs', line 182
def describe_cases: (
|
#describe_communications(params = {}) ⇒ Types::DescribeCommunicationsResponse
Returns communications and attachments for one or more support cases.
Use the afterTime and beforeTime parameters to filter by date. You
can use the caseId parameter to restrict the results to a specific
case.
Case data is available for 24 months after creation. If a case was created more than 24 months ago, a request for data might cause an error.
You can use the maxResults and nextToken parameters to control the
pagination of the results. Set maxResults to the number of cases
that you want to display on each page, and use nextToken to specify
the resumption of pagination.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
Each Communication returned by this operation includes attachment information in two fields:
-
attachmentSet: returns only attachments that are 5 MB or smaller. Attachments larger than 5 MB are not included in this field. -
attachments: returns all attachments regardless of size.
Amazon Web Services recommends that you use the attachments field
and download each attachment with GetAttachmentDownloadLink, which
supports attachments of any size. The attachmentSet field and
DescribeAttachment return only attachments that are 5 MB or smaller.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
202 |
# File 'sig/client.rbs', line 202
def describe_communications: (
|
#describe_create_case_options(params = {}) ⇒ Types::DescribeCreateCaseOptionsResponse
Returns a list of CreateCaseOption types along with the corresponding
supported hours and language availability. You can specify the
language categoryCode, issueType and serviceCode used to
retrieve the CreateCaseOptions.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
218 |
# File 'sig/client.rbs', line 218
def describe_create_case_options: (
|
#describe_services(params = {}) ⇒ Types::DescribeServicesResponse
Returns the current list of Amazon Web Services services and a list of service categories for each service. You then use service names and categories in your CreateCase requests. Each Amazon Web Services service has its own set of categories.
The service codes and category codes correspond to the values that
appear in the Service and Category lists on the Amazon Web
Services Support Center Create Case page. The values in those
fields don't necessarily match the service codes and categories
returned by the DescribeServices operation. Always use the service
codes and categories that the DescribeServices operation returns, so
that you have the most recent set of service and category codes.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
232 |
# File 'sig/client.rbs', line 232
def describe_services: (
|
#describe_severity_levels(params = {}) ⇒ Types::DescribeSeverityLevelsResponse
Returns the list of severity levels that you can assign to a support case. The severity level for a case is also a field in the CaseDetails data type that you include for a CreateCase request.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
244 |
# File 'sig/client.rbs', line 244
def describe_severity_levels: (
|
#describe_supported_languages(params = {}) ⇒ Types::DescribeSupportedLanguagesResponse
Returns a list of supported languages for a specified categoryCode,
issueType and serviceCode. The returned supported languages will
include a ISO 639-1 code for the language, and the language display
name.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
255 |
# File 'sig/client.rbs', line 255
def describe_supported_languages: (
|
#describe_trusted_advisor_check_refresh_statuses(params = {}) ⇒ Types::DescribeTrustedAdvisorCheckRefreshStatusesResponse
Returns the refresh status of the Trusted Advisor checks that have the specified check IDs. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
Some checks are refreshed automatically, and you can't return their
refresh statuses by using the
DescribeTrustedAdvisorCheckRefreshStatuses operation. If you call
this operation for these checks, you might see an
InvalidParameterValue error.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
To call the Trusted Advisor operations in the Amazon Web Services Support API, you must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support the Trusted Advisor operations. For more information, see About the Amazon Web Services Support API in the Amazon Web Services Support User Guide.
268 |
# File 'sig/client.rbs', line 268
def describe_trusted_advisor_check_refresh_statuses: (
|
#describe_trusted_advisor_check_result(params = {}) ⇒ Types::DescribeTrustedAdvisorCheckResultResponse
Returns the results of the Trusted Advisor check that has the specified check ID. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
The response contains a TrustedAdvisorCheckResult object, which contains these three objects:
-
TrustedAdvisorCategorySpecificSummary
-
TrustedAdvisorResourceDetail
-
TrustedAdvisorResourcesSummary
In addition, the response contains these fields:
-
status - The alert status of the check can be
ok(green),warning(yellow),error(red), ornot_available. -
timestamp - The time of the last refresh of the check.
-
checkId - The unique identifier for the check.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
To call the Trusted Advisor operations in the Amazon Web Services Support API, you must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support the Trusted Advisor operations. For more information, see About the Amazon Web Services Support API in the Amazon Web Services Support User Guide.
278 |
# File 'sig/client.rbs', line 278
def describe_trusted_advisor_check_result: (
|
#describe_trusted_advisor_check_summaries(params = {}) ⇒ Types::DescribeTrustedAdvisorCheckSummariesResponse
Returns the results for the Trusted Advisor check summaries for the check IDs that you specified. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
The response contains an array of TrustedAdvisorCheckSummary objects.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
To call the Trusted Advisor operations in the Amazon Web Services Support API, you must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support the Trusted Advisor operations. For more information, see About the Amazon Web Services Support API in the Amazon Web Services Support User Guide.
Understanding the Trusted Advisor Resources processed value
The Resources processed value, resourcesProcessed, usually shows
both flagged resources (those with warnings or errors) and resources
in good standing (ok status resources). However, some checks report
flagged resources only. To understand what a specific check reports,
review the detailed check information in the Trusted Advisor check
reference. If you see a Green criterion listed in the Alert
criteria, then the check reports all resources. If there's no
Green criterion listed in the Alert criteria, then the check
reports only flagged resources. For example, the Amazon EC2 Reserved
Instance optimization check (cX3c2R1chu) doesn't list a Green
criterion in the Alert criteria. So, this check only reports
flagged resources.
289 |
# File 'sig/client.rbs', line 289
def describe_trusted_advisor_check_summaries: (
|
#describe_trusted_advisor_checks(params = {}) ⇒ Types::DescribeTrustedAdvisorChecksResponse
Returns information about all available Trusted Advisor checks, including the name, ID, category, description, and metadata. You must specify a language code.
The response contains a TrustedAdvisorCheckDescription object for each check. You must set the Amazon Web Services Region to us-east-1.
-
If you call the Amazon Web Services Support API from an account that doesn't have a Amazon Web Services Business Support+, Amazon Web Services Enterprise Support, or Amazon Web Services Unified Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support. -
The names and descriptions for Trusted Advisor checks are subject to change. We recommend that you specify the check ID in your code to uniquely identify a check.
To call the Trusted Advisor operations in the Amazon Web Services Support API, you must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support the Trusted Advisor operations. For more information, see About the Amazon Web Services Support API in the Amazon Web Services Support User Guide.
299 |
# File 'sig/client.rbs', line 299
def describe_trusted_advisor_checks: (
|
#get_attachment_download_link(params = {}) ⇒ Types::GetAttachmentDownloadLinkResponse
Returns a presigned download URL for an attachment that is associated
with a case communication. The download link works for an attachment
of any size, including attachments added through AddAttachmentsToSet
and attachments uploaded through GetAttachmentUploadLinks. The
download URL is time-limited and expires at the date and time
indicated in the downloadUrl response field. Download the attachment
from the URL before it expires.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
310 |
# File 'sig/client.rbs', line 310
def get_attachment_download_link: (
|
#get_attachment_upload_links(params = {}) ⇒ Types::GetAttachmentUploadLinksResponse
Returns one or more presigned upload URLs for uploading a large file
attachment to a support case by using a multipart upload workflow. The
maximum file size that you can upload with this workflow is 150 MB,
and parts can be up to 100 MB each. Initiate a new upload by providing
fileName and fileSizeBytes; the response returns a unique
uploadId, the part size, the total number of parts, and a list of
presigned upload URLs for the requested range of parts. A maximum of
10 upload URLs are returned per call. To retrieve more upload URLs for
an upload that's already in progress, call GetAttachmentUploadLinks
again with the existing uploadId and a new uploadRange.
Upload each part to its presigned URL by using HTTP PUT and capture
the ETag from the response. After you upload all parts, call
CompleteAttachmentUpload with the uploadId and the list of part
indexes and ETags to finalize the upload. You can then attach the
upload to a case by passing the uploadId in the uploadIds
parameter of CreateCase or AddCommunicationToCase. To monitor progress
before completion, call DescribeAttachmentUploadStatus.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
325 |
# File 'sig/client.rbs', line 325
def get_attachment_upload_links: (
|
#refresh_trusted_advisor_check(params = {}) ⇒ Types::RefreshTrustedAdvisorCheckResponse
Refreshes the Trusted Advisor check that you specify using the check ID. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.
Some checks are refreshed automatically. If you call the
RefreshTrustedAdvisorCheck operation to refresh them, you might see
the InvalidParameterValue error.
The response contains a TrustedAdvisorCheckRefreshStatus object.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
To call the Trusted Advisor operations in the Amazon Web Services Support API, you must use the US East (N. Virginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support the Trusted Advisor operations. For more information, see About the Amazon Web Services Support API in the Amazon Web Services Support User Guide.
342 |
# File 'sig/client.rbs', line 342
def refresh_trusted_advisor_check: (
|
#resolve_case(params = {}) ⇒ Types::ResolveCaseResponse
Resolves a support case. This operation takes a caseId and returns
the initial and final state of the case.
- If you call the Amazon Web Services Support API from an account that
doesn't have an Amazon Web Services Business Support+, Amazon Web
Services Enterprise Support, or Amazon Web Services Unified
Operations plan, the
SubscriptionRequiredExceptionerror message appears. For information about changing your support plan, see Amazon Web Services Support.
353 |
# File 'sig/client.rbs', line 353
def resolve_case: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2392 2393 2394 |
# File 'lib/aws-sdk-support/client.rb', line 2392 def waiter_names [] end |