Method: Aws::Support::Client#resolve_case

Defined in:
lib/aws-sdk-support/client.rb

#resolve_case(params = {}) ⇒ Types::ResolveCaseResponse

Resolves a support case. This operation takes a caseId and returns the initial and final state of the case.

<note markdown=“1”> * You must have a Business, Enterprise On-Ramp, or Enterprise Support

plan to use the Amazon Web Services Support API.
  • If you call the Amazon Web Services Support API from an account that doesn’t have a Business, Enterprise On-Ramp, or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see [Amazon Web Services Support].

</note>

[1]: aws.amazon.com/premiumsupport/

Examples:

Request syntax with placeholder values


resp = client.resolve_case({
  case_id: "CaseId",
})

Response structure


resp.initial_case_status #=> String
resp.final_case_status #=> String

Options Hash (params):

  • :case_id (String)

    The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47

See Also:



1707
1708
1709
1710
# File 'lib/aws-sdk-support/client.rb', line 1707

def resolve_case(params = {}, options = {})
  req = build_request(:resolve_case, params)
  req.send_request(options)
end