Class: Aws::Support::Types::AddAttachmentsToSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_set_idString

The ID of the attachment set. If an attachmentSetId is not specified, a new attachment set is created, and the ID of the set is returned in the response. If an attachmentSetId is specified, the attachments are added to the specified set, if it exists.



41
42
43
44
45
46
47
# File 'lib/aws-sdk-support/types.rb', line 41

class AddAttachmentsToSetRequest < Struct.new(
  :attachment_set_id,
  :attachments,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#attachmentsArray<Types::Attachment>

One or more attachments to add to the set. You can add up to three attachments per set. The size limit is 5 MB per attachment.

In the Attachment object, use the data parameter to specify the contents of the attachment file. In the previous request syntax, the value for data appear as blob, which is represented as a base64-encoded string. The value for fileName is the name of the attachment, such as troubleshoot-screenshot.png.



41
42
43
44
45
46
47
# File 'lib/aws-sdk-support/types.rb', line 41

class AddAttachmentsToSetRequest < Struct.new(
  :attachment_set_id,
  :attachments,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Specifies whether to validate the request without actually adding the attachments. When set to true, the request is validated but no attachments are stored, and the operation returns a DryRunOperationException. When omitted or set to false, the request runs normally.



41
42
43
44
45
46
47
# File 'lib/aws-sdk-support/types.rb', line 41

class AddAttachmentsToSetRequest < Struct.new(
  :attachment_set_id,
  :attachments,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end