Class: Aws::Support::Types::AddCommunicationToCaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_set_idString

The ID of a set of one or more attachments for the communication to add to the case. Create the set by calling AddAttachmentsToSet. Each attachment in the set must be 5 MB or smaller. To attach files larger than 5 MB, use uploadIds.

Returns:



113
114
115
116
117
118
119
120
121
122
# File 'lib/aws-sdk-support/types.rb', line 113

class AddCommunicationToCaseRequest < Struct.new(
  :case_id,
  :communication_body,
  :cc_email_addresses,
  :attachment_set_id,
  :upload_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#case_idString

The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-exen-2025-c4c1d2bf33c5cf47

Returns:



113
114
115
116
117
118
119
120
121
122
# File 'lib/aws-sdk-support/types.rb', line 113

class AddCommunicationToCaseRequest < Struct.new(
  :case_id,
  :communication_body,
  :cc_email_addresses,
  :attachment_set_id,
  :upload_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#cc_email_addressesArray<String>

The email addresses in the CC line of an email to be added to the support case.

Returns:



113
114
115
116
117
118
119
120
121
122
# File 'lib/aws-sdk-support/types.rb', line 113

class AddCommunicationToCaseRequest < Struct.new(
  :case_id,
  :communication_body,
  :cc_email_addresses,
  :attachment_set_id,
  :upload_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#communication_bodyString

The body of an email communication to add to the support case.

Returns:



113
114
115
116
117
118
119
120
121
122
# File 'lib/aws-sdk-support/types.rb', line 113

class AddCommunicationToCaseRequest < Struct.new(
  :case_id,
  :communication_body,
  :cc_email_addresses,
  :attachment_set_id,
  :upload_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Specifies whether to validate the request without actually adding the communication to the case. When set to true, the request is validated but the communication isn't added, and the operation returns a DryRunOperationException. When omitted or set to false, the request runs normally.

Returns:



113
114
115
116
117
118
119
120
121
122
# File 'lib/aws-sdk-support/types.rb', line 113

class AddCommunicationToCaseRequest < Struct.new(
  :case_id,
  :communication_body,
  :cc_email_addresses,
  :attachment_set_id,
  :upload_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#upload_idsArray<String>

A list of upload IDs that identify attachments to add to the case. Each uploadId is returned by the GetAttachmentUploadLinks operation. The upload must reach the attachment-ready state by calling CompleteAttachmentUpload before it can be passed here. Use uploadIds to attach files of any supported size, including files larger than 5 MB.

Returns:



113
114
115
116
117
118
119
120
121
122
# File 'lib/aws-sdk-support/types.rb', line 113

class AddCommunicationToCaseRequest < Struct.new(
  :case_id,
  :communication_body,
  :cc_email_addresses,
  :attachment_set_id,
  :upload_ids,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end