Class: Aws::Support::Types::AttachmentLimitExceeded
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::AttachmentLimitExceeded
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
The limit for the number of attachment sets created in a short period of time has been exceeded.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The limit for the number of attachment sets created in a short period of time has been exceeded.
Instance Attribute Details
#message ⇒ String
The limit for the number of attachment sets created in a short period of time has been exceeded.
206 207 208 209 210 |
# File 'lib/aws-sdk-support/types.rb', line 206 class AttachmentLimitExceeded < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |