Class: Aws::Support::Types::CaseDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

A JSON-formatted object that contains the metadata for a support case. It is contained in the response from a DescribeCases request. CaseDetails contains the following fields:

  • caseId - The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-exen-2025-c4c1d2bf33c5cf47.

  • categoryCode - The category of problem for the support case. Corresponds to the CategoryCode values returned by a call to DescribeServices.

  • displayId - The identifier for the case on pages in the Amazon Web Services Support Center.

  • language - The language in which Amazon Web Services Support handles the case. Amazon Web Services Support currently supports Chinese (“zh”), English ("en"), Japanese ("ja") , Chinese ("zh"), Spanish ("es"), Portuguese ("pt"), French ("fr"), Korean (“ko”), and Turkish ("tr"). You must specify the ISO 639-1 code for the language parameter if you want support in that language.

  • nextToken - A resumption point for pagination.

  • recentCommunications - One or more Communication objects. Fields of these objects are attachments, body, caseId, submittedBy, and timeCreated.

  • serviceCode - The identifier for the Amazon Web Services service that corresponds to the service code defined in the call to DescribeServices.

  • severityCode - The severity code assigned to the case. Contains one of the values returned by the call to DescribeSeverityLevels. The possible values are: low, normal, high, urgent, and critical.

  • status - The status of the case in the Amazon Web Services Support Center. Valid values:

  • all-open

  • customer-action-completed

  • opened

  • pending-customer-action

  • reopened

  • resolved

  • unassigned

  • work-in-progress

  • subject - The subject line of the case.

  • submittedBy - The email address of the account that submitted the case.

  • timeCreated - The time the case was created, in ISO-8601 format.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#case_idString

The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-exen-2025-c4c1d2bf33c5cf47

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#category_codeString

The category of problem for the support case.

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#cc_email_addressesArray<String>

The email addresses that receive copies of communication about the case.

Returns:

  • (Array<String>)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#display_idString

The ID displayed for the case in the Amazon Web Services Support Center. This is a numeric string.

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#languageString

The language in which Amazon Web Services Support handles the case. Amazon Web Services Support currently supports Chinese (“zh”), English ("en"), Japanese ("ja") , Chinese ("zh"), Spanish ("es"), Portuguese ("pt"), French ("fr"), Korean (“ko”), and Turkish ("tr"). You must specify the ISO 639-1 code for the language parameter if you want support in that language.

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#recent_communicationsTypes::RecentCaseCommunications

The five most recent communications between you and Amazon Web Services Support Center, including the IDs of any attachments to the communications. Also includes a nextToken that you can use to retrieve earlier communications.



421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#service_codeString

The code for the Amazon Web Services service. You can get a list of codes and the corresponding service names by calling DescribeServices.

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#severity_codeString

The code for the severity level returned by the call to DescribeSeverityLevels.

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the case.

Valid values:

  • all-open

  • customer-action-completed

  • opened

  • pending-customer-action

  • reopened

  • resolved

  • unassigned

  • work-in-progress

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#subjectString

The subject line for the case in the Amazon Web Services Support Center.

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#submitted_byString

The email address of the account that submitted the case.

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end

#time_createdString

The time that the case was created in the Amazon Web Services Support Center.

Returns:

  • (String)


421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/aws-sdk-support/types.rb', line 421

class CaseDetails < Struct.new(
  :case_id,
  :display_id,
  :subject,
  :status,
  :service_code,
  :category_code,
  :severity_code,
  :submitted_by,
  :time_created,
  :recent_communications,
  :cc_email_addresses,
  :language)
  SENSITIVE = []
  include Aws::Structure
end