Class: Aws::Support::Types::Communication
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::Communication
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
A communication associated with a support case. The communication consists of the case ID, the message body, attachment information, the submitter of the communication, and the date and time of the communication.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_set ⇒ Array<Types::AttachmentDetails>
Information about the attachments to the case communication that are 5 MB or smaller.
-
#attachments ⇒ Array<Types::AttachmentDetails>
Information about all attachments on the case communication.
-
#body ⇒ String
The text of the communication between the customer and Amazon Web Services Support.
-
#case_id ⇒ String
The support case ID requested or returned in the call.
-
#submitted_by ⇒ String
The identity of the account that submitted, or responded to, the support case.
-
#time_created ⇒ String
The time the communication was created.
Instance Attribute Details
#attachment_set ⇒ Array<Types::AttachmentDetails>
Information about the attachments to the case communication that are
5 MB or smaller. This field doesn't include attachments larger than
5 MB. To enumerate every attachment on the communication, including
attachments larger than 5 MB, use the attachments field instead.
522 523 524 525 526 527 528 529 530 531 |
# File 'lib/aws-sdk-support/types.rb', line 522 class Communication < Struct.new( :case_id, :body, :submitted_by, :time_created, :attachments, :attachment_set) SENSITIVE = [] include Aws::Structure end |
#attachments ⇒ Array<Types::AttachmentDetails>
Information about all attachments on the case communication. This
includes attachments added through AddAttachmentsToSet and
attachments uploaded through GetAttachmentUploadLinks.
Use this field to enumerate every attachment on the communication.
To download an attachment listed in this field, use
GetAttachmentDownloadLink. GetAttachmentDownloadLink returns a
presigned URL that works for attachments of any size.
522 523 524 525 526 527 528 529 530 531 |
# File 'lib/aws-sdk-support/types.rb', line 522 class Communication < Struct.new( :case_id, :body, :submitted_by, :time_created, :attachments, :attachment_set) SENSITIVE = [] include Aws::Structure end |
#body ⇒ String
The text of the communication between the customer and Amazon Web Services Support.
522 523 524 525 526 527 528 529 530 531 |
# File 'lib/aws-sdk-support/types.rb', line 522 class Communication < Struct.new( :case_id, :body, :submitted_by, :time_created, :attachments, :attachment_set) SENSITIVE = [] include Aws::Structure end |
#case_id ⇒ String
The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-exen-2025-c4c1d2bf33c5cf47
522 523 524 525 526 527 528 529 530 531 |
# File 'lib/aws-sdk-support/types.rb', line 522 class Communication < Struct.new( :case_id, :body, :submitted_by, :time_created, :attachments, :attachment_set) SENSITIVE = [] include Aws::Structure end |
#submitted_by ⇒ String
The identity of the account that submitted, or responded to, the support case. Customer entries include the IAM role as well as the email address (for example, "AdminRole (Role) <[email protected]>). Entries from the Amazon Web Services Support team display "Amazon Web Services," and don't show an email address.
522 523 524 525 526 527 528 529 530 531 |
# File 'lib/aws-sdk-support/types.rb', line 522 class Communication < Struct.new( :case_id, :body, :submitted_by, :time_created, :attachments, :attachment_set) SENSITIVE = [] include Aws::Structure end |
#time_created ⇒ String
The time the communication was created.
522 523 524 525 526 527 528 529 530 531 |
# File 'lib/aws-sdk-support/types.rb', line 522 class Communication < Struct.new( :case_id, :body, :submitted_by, :time_created, :attachments, :attachment_set) SENSITIVE = [] include Aws::Structure end |