Class: Aws::Support::Types::CompleteAttachmentUploadResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::CompleteAttachmentUploadResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#upload_status ⇒ String
The status of the multipart upload after the operation finalizes the attachment.
Instance Attribute Details
#upload_status ⇒ String
The status of the multipart upload after the operation finalizes the
attachment. Valid values: attachment-ready,
attachment-not-ready, and failed.
612 613 614 615 616 |
# File 'lib/aws-sdk-support/types.rb', line 612 class CompleteAttachmentUploadResponse < Struct.new( :upload_status) SENSITIVE = [] include Aws::Structure end |