Class: Aws::Support::Types::DescribeAttachmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_idString

The ID of the attachment to return. Attachment IDs are returned by the DescribeCommunications operation.

If the specified attachment is larger than 5 MB, this operation returns InvalidParameterValueException. To download attachments larger than 5 MB, use GetAttachmentDownloadLink.

Returns:



836
837
838
839
840
841
# File 'lib/aws-sdk-support/types.rb', line 836

class DescribeAttachmentRequest < Struct.new(
  :attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Specifies whether to validate the request without actually retrieving the attachment. When set to true, the request is validated but no attachment content is returned, and the operation returns a DryRunOperationException. When omitted or set to false, the request runs normally.

Returns:



836
837
838
839
840
841
# File 'lib/aws-sdk-support/types.rb', line 836

class DescribeAttachmentRequest < Struct.new(
  :attachment_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end