Class: Aws::Support::Types::DescribeAttachmentUploadStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Specifies whether to validate the request without actually returning upload status. When set to true, the request is validated but no status is returned, and the operation returns a DryRunOperationException. When omitted or set to false, the request runs normally.

Returns:

  • (Boolean)


878
879
880
881
882
883
# File 'lib/aws-sdk-support/types.rb', line 878

class DescribeAttachmentUploadStatusRequest < Struct.new(
  :upload_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#upload_idString

The unique identifier for the upload. The uploadId is returned by GetAttachmentUploadLinks when you initiate the upload.

Returns:

  • (String)


878
879
880
881
882
883
# File 'lib/aws-sdk-support/types.rb', line 878

class DescribeAttachmentUploadStatusRequest < Struct.new(
  :upload_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end