Class: Aws::Support::Types::DescribeCasesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::DescribeCasesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Returns an array of CaseDetails objects and a nextToken that
defines a point for pagination in the result set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cases ⇒ Array<Types::CaseDetails>
The details for the cases that match the request.
-
#next_token ⇒ String
A resumption point for pagination.
Instance Attribute Details
#cases ⇒ Array<Types::CaseDetails>
The details for the cases that match the request.
1001 1002 1003 1004 1005 1006 |
# File 'lib/aws-sdk-support/types.rb', line 1001 class DescribeCasesResponse < Struct.new( :cases, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A resumption point for pagination.
1001 1002 1003 1004 1005 1006 |
# File 'lib/aws-sdk-support/types.rb', line 1001 class DescribeCasesResponse < Struct.new( :cases, :next_token) SENSITIVE = [] include Aws::Structure end |