Class: Aws::Support::Types::DescribeCommunicationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#after_timeString

The start date for a filtered date search on support case communications. Case communications are available for 24 months after creation.

Returns:

  • (String)


1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
# File 'lib/aws-sdk-support/types.rb', line 1044

class DescribeCommunicationsRequest < Struct.new(
  :case_id,
  :before_time,
  :after_time,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#before_timeString

The end date for a filtered date search on support case communications. Case communications are available for 24 months after creation.

Returns:

  • (String)


1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
# File 'lib/aws-sdk-support/types.rb', line 1044

class DescribeCommunicationsRequest < Struct.new(
  :case_id,
  :before_time,
  :after_time,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#case_idString

The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-exen-2025-c4c1d2bf33c5cf47

Returns:

  • (String)


1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
# File 'lib/aws-sdk-support/types.rb', line 1044

class DescribeCommunicationsRequest < Struct.new(
  :case_id,
  :before_time,
  :after_time,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Specifies whether to validate the request without actually returning communications. When set to true, the request is validated but no communications are returned, and the operation returns a DryRunOperationException. When omitted or set to false, the request runs normally.

Returns:

  • (Boolean)


1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
# File 'lib/aws-sdk-support/types.rb', line 1044

class DescribeCommunicationsRequest < Struct.new(
  :case_id,
  :before_time,
  :after_time,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return before paginating.

Returns:

  • (Integer)


1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
# File 'lib/aws-sdk-support/types.rb', line 1044

class DescribeCommunicationsRequest < Struct.new(
  :case_id,
  :before_time,
  :after_time,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A resumption point for pagination.

Returns:

  • (String)


1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
# File 'lib/aws-sdk-support/types.rb', line 1044

class DescribeCommunicationsRequest < Struct.new(
  :case_id,
  :before_time,
  :after_time,
  :next_token,
  :max_results,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end