Class: Aws::Support::Types::DescribeServicesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Specifies whether to validate the request without actually returning the list of services. When set to true, the request is validated but no services are returned, and the operation returns a DryRunOperationException. When omitted or set to false, the request runs normally.

Returns:

  • (Boolean)


1170
1171
1172
1173
1174
1175
1176
# File 'lib/aws-sdk-support/types.rb', line 1170

class DescribeServicesRequest < Struct.new(
  :service_code_list,
  :language,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#languageString

The language in which Amazon Web Services Support handles the case. Amazon Web Services Support currently supports Chinese (“zh”), English ("en"), Japanese ("ja") , Chinese ("zh"), Spanish ("es"), Portuguese ("pt"), French ("fr"), Korean (“ko”), and Turkish ("tr"). You must specify the ISO 639-1 code for the language parameter if you want support in that language.

Returns:

  • (String)


1170
1171
1172
1173
1174
1175
1176
# File 'lib/aws-sdk-support/types.rb', line 1170

class DescribeServicesRequest < Struct.new(
  :service_code_list,
  :language,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#service_code_listArray<String>

A JSON-formatted list of service codes available for Amazon Web Services services.

Returns:

  • (Array<String>)


1170
1171
1172
1173
1174
1175
1176
# File 'lib/aws-sdk-support/types.rb', line 1170

class DescribeServicesRequest < Struct.new(
  :service_code_list,
  :language,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end