Class: Aws::Support::Types::DownloadUrl

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

A presigned URL for downloading an attachment, along with the date and time the URL expires. Returned by GetAttachmentDownloadLink.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expiry_dateString

The date and time, in ISO-8601 format, when the presigned URL expires. Download the attachment before this time.



1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-support/types.rb', line 1472

class DownloadUrl < Struct.new(
  :url,
  :expiry_date)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The presigned HTTPS URL that you can use to download the attachment. Download URLs are served from downloadv1.attachments.support.{region}.amazonaws.com. The downloadv1 prefix is subject to change.



1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-support/types.rb', line 1472

class DownloadUrl < Struct.new(
  :url,
  :expiry_date)
  SENSITIVE = []
  include Aws::Structure
end