Class: Aws::Support::Types::GetAttachmentDownloadLinkResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::GetAttachmentDownloadLinkResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#download_url ⇒ Types::DownloadUrl
The presigned download URL and the date and time the URL expires.
-
#file_name ⇒ String
The name of the attachment file, including the file extension.
Instance Attribute Details
#download_url ⇒ Types::DownloadUrl
The presigned download URL and the date and time the URL expires.
1527 1528 1529 1530 1531 1532 |
# File 'lib/aws-sdk-support/types.rb', line 1527 class GetAttachmentDownloadLinkResponse < Struct.new( :file_name, :download_url) SENSITIVE = [] include Aws::Structure end |
#file_name ⇒ String
The name of the attachment file, including the file extension.
1527 1528 1529 1530 1531 1532 |
# File 'lib/aws-sdk-support/types.rb', line 1527 class GetAttachmentDownloadLinkResponse < Struct.new( :file_name, :download_url) SENSITIVE = [] include Aws::Structure end |