Class: Aws::Support::Types::GetAttachmentUploadLinksRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Specifies whether to validate the request without actually generating upload URLs. When set to true, the request is validated but no URLs are returned, and the operation returns a DryRunOperationException. When omitted or set to false, the request runs normally.

Returns:

  • (Boolean)


1572
1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/aws-sdk-support/types.rb', line 1572

class GetAttachmentUploadLinksRequest < Struct.new(
  :file_name,
  :file_size_bytes,
  :upload_id,
  :upload_range,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#file_nameString

The name of the file to upload, including the file extension. This value is required when you initiate a new upload.

Returns:

  • (String)


1572
1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/aws-sdk-support/types.rb', line 1572

class GetAttachmentUploadLinksRequest < Struct.new(
  :file_name,
  :file_size_bytes,
  :upload_id,
  :upload_range,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#file_size_bytesInteger

The total size of the file in bytes. The service uses this value to calculate the total number of parts and the size of each part. Required when you initiate a new upload (when uploadId isn't provided). Valid range: 1 to 157,286,400 bytes (approximately 150 MB).

Returns:

  • (Integer)


1572
1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/aws-sdk-support/types.rb', line 1572

class GetAttachmentUploadLinksRequest < Struct.new(
  :file_name,
  :file_size_bytes,
  :upload_id,
  :upload_range,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#upload_idString

The unique identifier of an in-progress multipart upload, returned by a previous call to GetAttachmentUploadLinks. Specify uploadId to retrieve additional presigned upload URLs for an upload that has already been initiated. Required when fileSizeBytes isn't provided. Length: 1 to 2,048 characters.

Returns:

  • (String)


1572
1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/aws-sdk-support/types.rb', line 1572

class GetAttachmentUploadLinksRequest < Struct.new(
  :file_name,
  :file_size_bytes,
  :upload_id,
  :upload_range,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#upload_rangeTypes::UploadRange

The range of part indexes for which to return presigned upload URLs. Use this parameter to page through the upload URLs for a large file across multiple calls. If you omit this parameter, the service determines the range to return.

Returns:



1572
1573
1574
1575
1576
1577
1578
1579
1580
# File 'lib/aws-sdk-support/types.rb', line 1572

class GetAttachmentUploadLinksRequest < Struct.new(
  :file_name,
  :file_size_bytes,
  :upload_id,
  :upload_range,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end