Class: Aws::Support::Types::GetAttachmentUploadLinksResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_indexInteger

The next part index to request presigned URLs for. If all upload URLs for the file have been returned, this field is null. Use this value as the startIndex in uploadRange on a subsequent call to GetAttachmentUploadLinks to retrieve the next batch of upload URLs.

Returns:

  • (Integer)


1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-support/types.rb', line 1619

class GetAttachmentUploadLinksResponse < Struct.new(
  :upload_id,
  :part_size_bytes,
  :total_parts,
  :next_index,
  :upload_urls)
  SENSITIVE = []
  include Aws::Structure
end

#part_size_bytesInteger

The size, in bytes, of each part. Split the file into parts of this size before you upload them to the presigned URLs. For an upload with n total parts, parts 1 through n - 1 are exactly this size; the last part may be smaller. Maximum: 104,857,600 bytes (approximately 100 MB).

Returns:

  • (Integer)


1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-support/types.rb', line 1619

class GetAttachmentUploadLinksResponse < Struct.new(
  :upload_id,
  :part_size_bytes,
  :total_parts,
  :next_index,
  :upload_urls)
  SENSITIVE = []
  include Aws::Structure
end

#total_partsInteger

The total number of parts that the file is split into. Upload one part to each presigned URL.

Returns:

  • (Integer)


1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-support/types.rb', line 1619

class GetAttachmentUploadLinksResponse < Struct.new(
  :upload_id,
  :part_size_bytes,
  :total_parts,
  :next_index,
  :upload_urls)
  SENSITIVE = []
  include Aws::Structure
end

#upload_idString

The unique identifier for the multipart upload. Use this value in subsequent calls to GetAttachmentUploadLinks, DescribeAttachmentUploadStatus, and CompleteAttachmentUpload, and to attach the upload to a case through the uploadIds parameter on CreateCase or AddCommunicationToCase.

Returns:

  • (String)


1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-support/types.rb', line 1619

class GetAttachmentUploadLinksResponse < Struct.new(
  :upload_id,
  :part_size_bytes,
  :total_parts,
  :next_index,
  :upload_urls)
  SENSITIVE = []
  include Aws::Structure
end

#upload_urlsArray<Types::UploadUrl>

The list of presigned upload URLs for the requested range of parts. The list contains at most 10 URLs per call. Upload each part to its corresponding URL by using HTTP PUT before the URL expires.

Returns:



1619
1620
1621
1622
1623
1624
1625
1626
1627
# File 'lib/aws-sdk-support/types.rb', line 1619

class GetAttachmentUploadLinksResponse < Struct.new(
  :upload_id,
  :part_size_bytes,
  :total_parts,
  :next_index,
  :upload_urls)
  SENSITIVE = []
  include Aws::Structure
end