Class: Aws::Support::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::ThrottlingException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
You have exceeded the maximum allowed TPS (Transactions Per Second) for the operations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#throttling_reasons ⇒ Array<Types::ThrottlingReason>
A list of one or more reasons that the request was throttled.
Instance Attribute Details
#message ⇒ String
1881 1882 1883 1884 1885 1886 |
# File 'lib/aws-sdk-support/types.rb', line 1881 class ThrottlingException < Struct.new( :message, :throttling_reasons) SENSITIVE = [] include Aws::Structure end |
#throttling_reasons ⇒ Array<Types::ThrottlingReason>
A list of one or more reasons that the request was throttled.
1881 1882 1883 1884 1885 1886 |
# File 'lib/aws-sdk-support/types.rb', line 1881 class ThrottlingException < Struct.new( :message, :throttling_reasons) SENSITIVE = [] include Aws::Structure end |