Class: Aws::Support::Types::ThrottlingReason
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::ThrottlingReason
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Information about why a request was throttled.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#reason ⇒ String
The reason that the request was throttled.
-
#resource ⇒ String
The resource that caused the request to be throttled.
Instance Attribute Details
#reason ⇒ String
The reason that the request was throttled.
1900 1901 1902 1903 1904 1905 |
# File 'lib/aws-sdk-support/types.rb', line 1900 class ThrottlingReason < Struct.new( :reason, :resource) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ String
The resource that caused the request to be throttled.
1900 1901 1902 1903 1904 1905 |
# File 'lib/aws-sdk-support/types.rb', line 1900 class ThrottlingReason < Struct.new( :reason, :resource) SENSITIVE = [] include Aws::Structure end |