Class: Aws::Support::Types::UploadProgress

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-support/types.rb

Overview

The progress of a multipart attachment upload, returned by DescribeAttachmentUploadStatus.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completed_parts_countInteger

The number of parts that have been successfully uploaded.

Returns:

  • (Integer)


2213
2214
2215
2216
2217
2218
# File 'lib/aws-sdk-support/types.rb', line 2213

class UploadProgress < Struct.new(
  :total_parts,
  :completed_parts_count)
  SENSITIVE = []
  include Aws::Structure
end

#total_partsInteger

The total number of parts that the file is split into.

Returns:

  • (Integer)


2213
2214
2215
2216
2217
2218
# File 'lib/aws-sdk-support/types.rb', line 2213

class UploadProgress < Struct.new(
  :total_parts,
  :completed_parts_count)
  SENSITIVE = []
  include Aws::Structure
end