Class: Aws::Support::Types::CompleteAttachmentUploadRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::CompleteAttachmentUploadRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_uploads ⇒ Array<Types::CompletedUpload>
The list of parts being reported as completed in this call.
-
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually completing the upload.
-
#upload_id ⇒ String
The identifier associated with the upload to complete.
Instance Attribute Details
#completed_uploads ⇒ Array<Types::CompletedUpload>
The list of parts being reported as completed in this call. Each
entry must contain the partIndex of an uploaded part and the
ETag returned by Amazon S3 when that part was uploaded.
596 597 598 599 600 601 602 |
# File 'lib/aws-sdk-support/types.rb', line 596 class CompleteAttachmentUploadRequest < Struct.new( :upload_id, :completed_uploads, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually
completing the upload. When set to true, the request is validated
but the upload isn't finalized, and the operation returns a
DryRunOperationException. When omitted or set to false, the
request runs normally.
596 597 598 599 600 601 602 |
# File 'lib/aws-sdk-support/types.rb', line 596 class CompleteAttachmentUploadRequest < Struct.new( :upload_id, :completed_uploads, :dry_run) SENSITIVE = [] include Aws::Structure end |
#upload_id ⇒ String
The identifier associated with the upload to complete.
596 597 598 599 600 601 602 |
# File 'lib/aws-sdk-support/types.rb', line 596 class CompleteAttachmentUploadRequest < Struct.new( :upload_id, :completed_uploads, :dry_run) SENSITIVE = [] include Aws::Structure end |