Class: Aws::Support::Types::CompletedUpload
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::CompletedUpload
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Identifies a single uploaded part of a multipart attachment upload.
Pass a list of CompletedUpload objects to CompleteAttachmentUpload
to finalize the upload.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#e_tag ⇒ String
The ETag returned in the response headers when the part was uploaded to Amazon S3.
-
#part_index ⇒ Integer
The index of the uploaded part.
Instance Attribute Details
#e_tag ⇒ String
The ETag returned in the response headers when the part was uploaded
to Amazon S3. The ETag value identifies the part contents.
635 636 637 638 639 640 |
# File 'lib/aws-sdk-support/types.rb', line 635 class CompletedUpload < Struct.new( :part_index, :e_tag) SENSITIVE = [] include Aws::Structure end |
#part_index ⇒ Integer
The index of the uploaded part. This is the same partIndex value
returned for the corresponding entry in the uploadUrls field of
the GetAttachmentUploadLinks response.
635 636 637 638 639 640 |
# File 'lib/aws-sdk-support/types.rb', line 635 class CompletedUpload < Struct.new( :part_index, :e_tag) SENSITIVE = [] include Aws::Structure end |