Class: Aws::Support::Types::CreateCaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::CreateCaseRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_set_id ⇒ String
The ID of a set of one or more attachments for the case.
-
#category_code ⇒ String
The category of problem for the support case.
-
#cc_email_addresses ⇒ Array<String>
A list of email addresses that Amazon Web Services Support copies on case correspondence.
-
#communication_body ⇒ String
The communication body text that describes the issue.
-
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually creating the case.
-
#issue_type ⇒ String
The type of issue for the case.
-
#language ⇒ String
The language in which Amazon Web Services Support handles the case.
-
#service_code ⇒ String
The code for the Amazon Web Services service.
-
#severity_code ⇒ String
A value that indicates the urgency of the case.
-
#subject ⇒ String
The title of the support case.
-
#upload_ids ⇒ Array<String>
A list of upload IDs that identify attachments to add to the case.
Instance Attribute Details
#attachment_set_id ⇒ String
The ID of a set of one or more attachments for the case. Create the
set by using the AddAttachmentsToSet operation. Each attachment in
the set must be 5 MB or smaller. To attach files larger than 5 MB,
use uploadIds.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#category_code ⇒ String
The category of problem for the support case. You also use the DescribeServices operation to get the category code for a service. Each Amazon Web Services service defines its own set of category codes.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#cc_email_addresses ⇒ Array<String>
A list of email addresses that Amazon Web Services Support copies on case correspondence. Amazon Web Services Support identifies the account that creates the case when you specify your Amazon Web Services credentials in an HTTP POST method or use the Amazon Web Services SDKs.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#communication_body ⇒ String
The communication body text that describes the issue. This text appears in the Description field on the Amazon Web Services Support Center Create Case page.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually creating
the case. When set to true, the request is validated but no case
is created, and the operation returns a DryRunOperationException.
When omitted or set to false, the request runs normally.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#issue_type ⇒ String
The type of issue for the case. You can specify customer-service
or technical. If you don't specify a value, the default is
technical.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#language ⇒ String
The language in which Amazon Web Services Support handles the case.
Amazon Web Services Support currently supports Chinese (“zh”),
English ("en"), Japanese ("ja") , Chinese ("zh"), Spanish
("es"), Portuguese ("pt"), French ("fr"), Korean (“ko”), and
Turkish ("tr"). You must specify the ISO 639-1 code for the
language parameter if you want support in that language.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
The code for the Amazon Web Services service. You can use the
DescribeServices operation to get the possible serviceCode values.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#severity_code ⇒ String
A value that indicates the urgency of the case. This value
determines the response time according to your service level
agreement with Amazon Web Services Support. You can use the
DescribeSeverityLevels operation to get the possible values for
severityCode.
For more information, see SeverityLevel and Choosing a Severity in the Amazon Web Services Support User Guide.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#subject ⇒ String
The title of the support case. The title appears in the Subject field on the Amazon Web Services Support Center Create Case page.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |
#upload_ids ⇒ Array<String>
A list of upload IDs that identify attachments to add to the case.
Each uploadId is returned by the GetAttachmentUploadLinks
operation. The upload must reach the attachment-ready state by
calling CompleteAttachmentUpload before it can be passed here. Use
uploadIds to attach files of any supported size, including files
larger than 5 MB.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/aws-sdk-support/types.rb', line 746 class CreateCaseRequest < Struct.new( :subject, :service_code, :severity_code, :category_code, :communication_body, :cc_email_addresses, :language, :issue_type, :attachment_set_id, :upload_ids, :dry_run) SENSITIVE = [] include Aws::Structure end |