Class: Aws::Support::Types::DescribeAttachmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::DescribeAttachmentResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
The content and file name of the attachment returned by the DescribeAttachment operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment ⇒ Types::Attachment
This object includes the attachment content and file name.
Instance Attribute Details
#attachment ⇒ Types::Attachment
This object includes the attachment content and file name.
In the previous response syntax, the value for the data parameter appears as blob, which is represented as a base64-encoded string. The value for fileName is the name of the attachment, such as troubleshoot-screenshot.png.
709 710 711 712 713 |
# File 'lib/aws-sdk-support/types.rb', line 709 class DescribeAttachmentResponse < Struct.new( :attachment) SENSITIVE = [] include Aws::Structure end |