Class: Aws::Support::Types::DescribeAttachmentUploadStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::DescribeAttachmentUploadStatusRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning upload status.
-
#upload_id ⇒ String
The unique identifier for the upload.
Instance Attribute Details
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning
upload status. When set to true, the request is validated but no
status is returned, and the operation returns a
DryRunOperationException. When omitted or set to false, the
request runs normally.
878 879 880 881 882 883 |
# File 'lib/aws-sdk-support/types.rb', line 878 class DescribeAttachmentUploadStatusRequest < Struct.new( :upload_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#upload_id ⇒ String
The unique identifier for the upload. The uploadId is returned by
GetAttachmentUploadLinks when you initiate the upload.
878 879 880 881 882 883 |
# File 'lib/aws-sdk-support/types.rb', line 878 class DescribeAttachmentUploadStatusRequest < Struct.new( :upload_id, :dry_run) SENSITIVE = [] include Aws::Structure end |