Class: Aws::Support::Types::DescribeAttachmentUploadStatusResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::DescribeAttachmentUploadStatusResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_name ⇒ String
The name of the file being uploaded, including the file extension.
-
#upload_progress ⇒ Types::UploadProgress
The progress of the multipart upload, including the total number of parts and the number of parts that have been successfully uploaded.
-
#upload_status ⇒ String
The current status of the multipart upload.
Instance Attribute Details
#file_name ⇒ String
The name of the file being uploaded, including the file extension.
901 902 903 904 905 906 907 |
# File 'lib/aws-sdk-support/types.rb', line 901 class DescribeAttachmentUploadStatusResponse < Struct.new( :upload_status, :file_name, :upload_progress) SENSITIVE = [] include Aws::Structure end |
#upload_progress ⇒ Types::UploadProgress
The progress of the multipart upload, including the total number of parts and the number of parts that have been successfully uploaded.
901 902 903 904 905 906 907 |
# File 'lib/aws-sdk-support/types.rb', line 901 class DescribeAttachmentUploadStatusResponse < Struct.new( :upload_status, :file_name, :upload_progress) SENSITIVE = [] include Aws::Structure end |
#upload_status ⇒ String
The current status of the multipart upload. Valid values:
attachment-ready, attachment-not-ready, and failed.
901 902 903 904 905 906 907 |
# File 'lib/aws-sdk-support/types.rb', line 901 class DescribeAttachmentUploadStatusResponse < Struct.new( :upload_status, :file_name, :upload_progress) SENSITIVE = [] include Aws::Structure end |