Class: Aws::Support::Types::DescribeCasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::DescribeCasesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_time ⇒ String
The start date for a filtered date search on support case communications.
-
#before_time ⇒ String
The end date for a filtered date search on support case communications.
-
#case_id_list ⇒ Array<String>
A list of ID numbers of the support cases you want returned.
-
#display_id ⇒ String
The ID displayed for a case in the Amazon Web Services Support Center user interface.
-
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning case data.
-
#include_communications ⇒ Boolean
Specifies whether to include communications in the
DescribeCasesresponse. -
#include_resolved_cases ⇒ Boolean
Specifies whether to include resolved support cases in the
DescribeCasesresponse. -
#language ⇒ String
The language in which Amazon Web Services Support handles the case.
-
#max_results ⇒ Integer
The maximum number of results to return before paginating.
-
#next_token ⇒ String
A resumption point for pagination.
Instance Attribute Details
#after_time ⇒ String
The start date for a filtered date search on support case communications. Case communications are available for 24 months after creation.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#before_time ⇒ String
The end date for a filtered date search on support case communications. Case communications are available for 24 months after creation.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#case_id_list ⇒ Array<String>
A list of ID numbers of the support cases you want returned. The maximum number of cases is 100.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#display_id ⇒ String
The ID displayed for a case in the Amazon Web Services Support Center user interface.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning
case data. When set to true, the request is validated but no cases
are returned, and the operation returns a
DryRunOperationException. When omitted or set to false, the
request runs normally.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#include_communications ⇒ Boolean
Specifies whether to include communications in the DescribeCases
response. By default, communications are included.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#include_resolved_cases ⇒ Boolean
Specifies whether to include resolved support cases in the
DescribeCases response. By default, resolved cases aren't
included.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#language ⇒ String
The language in which Amazon Web Services Support handles the case.
Amazon Web Services Support currently supports Chinese (“zh”),
English ("en"), Japanese ("ja") , Chinese ("zh"), Spanish
("es"), Portuguese ("pt"), French ("fr"), Korean (“ko”), and
Turkish ("tr"). You must specify the ISO 639-1 code for the
language parameter if you want support in that language.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return before paginating.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A resumption point for pagination.
969 970 971 972 973 974 975 976 977 978 979 980 981 982 |
# File 'lib/aws-sdk-support/types.rb', line 969 class DescribeCasesRequest < Struct.new( :case_id_list, :display_id, :after_time, :before_time, :include_resolved_cases, :next_token, :max_results, :language, :include_communications, :dry_run) SENSITIVE = [] include Aws::Structure end |