Class: Aws::Support::Types::DescribeCommunicationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::DescribeCommunicationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_time ⇒ String
The start date for a filtered date search on support case communications.
-
#before_time ⇒ String
The end date for a filtered date search on support case communications.
-
#case_id ⇒ String
The support case ID requested or returned in the call.
-
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning communications.
-
#max_results ⇒ Integer
The maximum number of results to return before paginating.
-
#next_token ⇒ String
A resumption point for pagination.
Instance Attribute Details
#after_time ⇒ String
The start date for a filtered date search on support case communications. Case communications are available for 24 months after creation.
1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-support/types.rb', line 1044 class DescribeCommunicationsRequest < Struct.new( :case_id, :before_time, :after_time, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#before_time ⇒ String
The end date for a filtered date search on support case communications. Case communications are available for 24 months after creation.
1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-support/types.rb', line 1044 class DescribeCommunicationsRequest < Struct.new( :case_id, :before_time, :after_time, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#case_id ⇒ String
The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-exen-2025-c4c1d2bf33c5cf47
1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-support/types.rb', line 1044 class DescribeCommunicationsRequest < Struct.new( :case_id, :before_time, :after_time, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning
communications. When set to true, the request is validated but no
communications are returned, and the operation returns a
DryRunOperationException. When omitted or set to false, the
request runs normally.
1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-support/types.rb', line 1044 class DescribeCommunicationsRequest < Struct.new( :case_id, :before_time, :after_time, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return before paginating.
1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-support/types.rb', line 1044 class DescribeCommunicationsRequest < Struct.new( :case_id, :before_time, :after_time, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A resumption point for pagination.
1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-support/types.rb', line 1044 class DescribeCommunicationsRequest < Struct.new( :case_id, :before_time, :after_time, :next_token, :max_results, :dry_run) SENSITIVE = [] include Aws::Structure end |