Class: Aws::Support::Types::DescribeCreateCaseOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::DescribeCreateCaseOptionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category_code ⇒ String
The category of problem for the support case.
-
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning case option data.
-
#issue_type ⇒ String
The type of issue for the case.
-
#language ⇒ String
The language in which Amazon Web Services Support handles the case.
-
#service_code ⇒ String
The code for the Amazon Web Services service.
Instance Attribute Details
#category_code ⇒ String
The category of problem for the support case. You also use the DescribeServices operation to get the category code for a service. Each Amazon Web Services service defines its own set of category codes.
1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'lib/aws-sdk-support/types.rb', line 1111 class DescribeCreateCaseOptionsRequest < Struct.new( :issue_type, :service_code, :language, :category_code, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning
case option data. When set to true, the request is validated but
no options are returned, and the operation returns a
DryRunOperationException. When omitted or set to false, the
request runs normally.
1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'lib/aws-sdk-support/types.rb', line 1111 class DescribeCreateCaseOptionsRequest < Struct.new( :issue_type, :service_code, :language, :category_code, :dry_run) SENSITIVE = [] include Aws::Structure end |
#issue_type ⇒ String
The type of issue for the case. You can specify customer-service
or technical. If you don't specify a value, the default is
technical.
1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'lib/aws-sdk-support/types.rb', line 1111 class DescribeCreateCaseOptionsRequest < Struct.new( :issue_type, :service_code, :language, :category_code, :dry_run) SENSITIVE = [] include Aws::Structure end |
#language ⇒ String
The language in which Amazon Web Services Support handles the case.
Amazon Web Services Support currently supports Chinese (“zh”),
English ("en"), Japanese ("ja") , Chinese ("zh"), Spanish
("es"), Portuguese ("pt"), French ("fr"), Korean (“ko”), and
Turkish ("tr"). You must specify the ISO 639-1 code for the
language parameter if you want support in that language.
1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'lib/aws-sdk-support/types.rb', line 1111 class DescribeCreateCaseOptionsRequest < Struct.new( :issue_type, :service_code, :language, :category_code, :dry_run) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
The code for the Amazon Web Services service. You can use the
DescribeServices operation to get the possible serviceCode values.
1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'lib/aws-sdk-support/types.rb', line 1111 class DescribeCreateCaseOptionsRequest < Struct.new( :issue_type, :service_code, :language, :category_code, :dry_run) SENSITIVE = [] include Aws::Structure end |