Class: Aws::Support::Types::DescribeSeverityLevelsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::DescribeSeverityLevelsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning severity levels.
-
#language ⇒ String
The language in which Amazon Web Services Support handles the case.
Instance Attribute Details
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning
severity levels. When set to true, the request is validated but no
severity levels are returned, and the operation returns a
DryRunOperationException. When omitted or set to false, the
request runs normally.
1212 1213 1214 1215 1216 1217 |
# File 'lib/aws-sdk-support/types.rb', line 1212 class DescribeSeverityLevelsRequest < Struct.new( :language, :dry_run) SENSITIVE = [] include Aws::Structure end |
#language ⇒ String
The language in which Amazon Web Services Support handles the case.
Amazon Web Services Support currently supports Chinese (“zh”),
English ("en"), Japanese ("ja") , Chinese ("zh"), Spanish
("es"), Portuguese ("pt"), French ("fr"), Korean (“ko”), and
Turkish ("tr"). You must specify the ISO 639-1 code for the
language parameter if you want support in that language.
1212 1213 1214 1215 1216 1217 |
# File 'lib/aws-sdk-support/types.rb', line 1212 class DescribeSeverityLevelsRequest < Struct.new( :language, :dry_run) SENSITIVE = [] include Aws::Structure end |