Class: Aws::Support::Types::GetAttachmentDownloadLinkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::GetAttachmentDownloadLinkRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_id ⇒ String
The unique identifier of the attachment for which to retrieve a download link.
-
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning a download link.
Instance Attribute Details
#attachment_id ⇒ String
The unique identifier of the attachment for which to retrieve a
download link. Attachment IDs are returned in the
AttachmentDetails objects in the attachments field of a
Communication returned by DescribeCommunications or DescribeCases.
1510 1511 1512 1513 1514 1515 |
# File 'lib/aws-sdk-support/types.rb', line 1510 class GetAttachmentDownloadLinkRequest < Struct.new( :attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually returning
a download link. When set to true, the request is validated but no
URL is returned, and the operation returns a
DryRunOperationException. When omitted or set to false, the
request runs normally.
1510 1511 1512 1513 1514 1515 |
# File 'lib/aws-sdk-support/types.rb', line 1510 class GetAttachmentDownloadLinkRequest < Struct.new( :attachment_id, :dry_run) SENSITIVE = [] include Aws::Structure end |