Class: Aws::Support::Types::ResolveCaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::ResolveCaseRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#case_id ⇒ String
The support case ID requested or returned in the call.
-
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually resolving the case.
Instance Attribute Details
#case_id ⇒ String
The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-exen-2025-c4c1d2bf33c5cf47
1710 1711 1712 1713 1714 1715 |
# File 'lib/aws-sdk-support/types.rb', line 1710 class ResolveCaseRequest < Struct.new( :case_id, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Specifies whether to validate the request without actually resolving
the case. When set to true, the request is validated but the case
isn't resolved, and the operation returns a
DryRunOperationException. When omitted or set to false, the
request runs normally.
1710 1711 1712 1713 1714 1715 |
# File 'lib/aws-sdk-support/types.rb', line 1710 class ResolveCaseRequest < Struct.new( :case_id, :dry_run) SENSITIVE = [] include Aws::Structure end |