Class: Aws::Support::Types::SeverityLevel
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::SeverityLevel
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
A code and name pair that represents the severity level of a support case. The available values depend on the support plan for the account. For more information, see Choosing a severity in the Amazon Web Services Support User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The code for case severity level.
-
#name ⇒ String
The name of the severity level that corresponds to the severity level code.
Instance Attribute Details
#code ⇒ String
The code for case severity level.
Valid values: low | normal | high | urgent | critical
1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-support/types.rb', line 1816 class SeverityLevel < Struct.new( :code, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the severity level that corresponds to the severity level code.
low, but the name appears as General guidance in
Support Center.
The following are the API code names and how they appear in the console:
-
low- General guidance -
normal- System impaired -
high- Production system impaired -
urgent- Production system down -
critical- Business-critical system down
For more information, see Choosing a severity in the Amazon Web Services Support User Guide.
1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-support/types.rb', line 1816 class SeverityLevel < Struct.new( :code, :name) SENSITIVE = [] include Aws::Structure end |