Class: Aws::Support::Types::UploadUrl
- Inherits:
-
Struct
- Object
- Struct
- Aws::Support::Types::UploadUrl
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-support/types.rb
Overview
A presigned URL for uploading a single part of a multipart attachment upload, along with the part index and the date and time the URL expires. Returned by GetAttachmentUploadLinks.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expiry_date ⇒ String
The date and time, in ISO-8601 format, when the presigned URL expires.
-
#part_index ⇒ Integer
The index of the part that this URL uploads.
-
#url ⇒ String
The presigned HTTPS URL that you use to upload a single part with HTTP
PUT.
Instance Attribute Details
#expiry_date ⇒ String
The date and time, in ISO-8601 format, when the presigned URL expires. Upload the part before this time.
2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-support/types.rb', line 2269 class UploadUrl < Struct.new( :url, :part_index, :expiry_date) SENSITIVE = [] include Aws::Structure end |
#part_index ⇒ Integer
The index of the part that this URL uploads.
2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-support/types.rb', line 2269 class UploadUrl < Struct.new( :url, :part_index, :expiry_date) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The presigned HTTPS URL that you use to upload a single part with
HTTP PUT. Upload URLs are served from
uploadv1.attachments.support.{region}.amazonaws.com. The
uploadv1 prefix is subject to change.
2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-support/types.rb', line 2269 class UploadUrl < Struct.new( :url, :part_index, :expiry_date) SENSITIVE = [] include Aws::Structure end |